@@ -1,7 +1,7 @@
 /*
  * frogr-util.c -- Misc tools.
  *
- * Copyright (C) 2010-2014 Mario Sanchez Prada
+ * Copyright (C) 2010-2016 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -111,7 +111,7 @@ frogr_util_get_locale_dir (void)
     {
 #ifndef PLATFORM_MAC
       /* If not in MacOSX, we trust the defined variable better */
-      locale_dir = g_strdup (FROGR_LOCALE_DIR);
+      locale_dir = g_strdup (LOCALEDIR);
 #endif
 
       /* Fallback for MacOSX and cases where FROGR_LOCALE_DIR was not
@@ -167,7 +167,7 @@ _open_uris_with_app_info (GList *uris_list, GAppInfo *app_info)
       /* In MacOSX use 'open' instead of 'xdg-open' */
       command = g_strdup_printf ("open %s", uris);
 #else
-      command = g_strdup_printf ("xdg-open %s", uris);
+      command = g_strdup_printf ("gvfs-open %s", uris);
 #endif
       _spawn_command (command);
 
