@@ -2,7 +2,7 @@
  * frogr-util.h -- Misc tools.
  *
  * Copyright (C) 2010-2012 Mario Sanchez Prada
- * Authors: Mario Sanchez Prada <msanchez@igalia.com>
+ * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 3 of the GNU General Public
@@ -33,7 +33,7 @@ const gchar *frogr_util_get_locale_dir (void);
 
 void frogr_util_open_uri (const gchar *uri);
 
-void frogr_util_open_images_in_viewer (GList *uris_list);
+void frogr_util_open_pictures_in_viewer (GSList *pictures);
 
 void frogr_util_show_info_dialog (GtkWindow *parent, const gchar *message);
 
@@ -41,10 +41,14 @@ void frogr_util_show_warning_dialog (GtkWindow *parent, const gchar *message);
 
 void frogr_util_show_error_dialog (GtkWindow *parent, const gchar *message);
 
-GdkPixbuf *frogr_util_get_corrected_pixbuf (GdkPixbuf *pixbuf, gint max_width, gint max_height);
+GdkPixbuf *frogr_util_get_pixbuf_for_video_file (GFile *file, gint max_width, gint max_height, GError **error);
+
+GdkPixbuf *frogr_util_get_pixbuf_from_image_contents (const guchar *contents, gsize length, gint max_width, gint max_height, GError **error);
 
 gchar *frogr_util_get_datasize_string (gulong datasize);
 
+const gchar * const *frogr_util_get_supported_mimetypes (void);
+
 G_END_DECLS
 
 #endif /* FROGR_UTIL_H */
